# crownstone-lib-python-core

This is the core of the python lib. It contains shared classes, definitions and utils. This is not intended for direct use by external
parties. Take a a look at the specialized libraries for your purpose:


- https://github.com/crownstone/crownstone-lib-python-uart
- https://github.com/crownstone/crownstone-lib-python-ble
- https://github.com/crownstone/crownstone-lib-python-cloud
- https://github.com/crownstone/crownstone-lib-python-sse

If you wish to install all crownstone python libraries, take a look at our [tutorial](./docs/TUTORIAL_VENV_SETUP.md).